==> spip_3.2.11.orig.tar.xz: plugins-dist/medias/lang/medias_wo.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=wo
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_ajouter_document' => 'Dolli ab jukki', # MODIF
	'bouton_ajouter_image' => 'Dolli ab nataal', # MODIF

	// E
	'entree_dimensions' => 'Tolluwaay yi',
	'entree_titre_document' => 'Boppu jukki bi',
	'entree_titre_image' => 'Boppu nataal bi',

	// I
	'image_tourner_180' => 'Wëndeel 180°',
	'image_tourner_droite' => 'Wëndeel 90° ci ndeyjoor',
	'image_tourner_gauche' => 'Wëndeel 90° ci cammooñ',
	'info_document' => 'Jukku;',
	'info_documents' => 'Jukk;',
	'info_inclusion_directe' => 'Boole bu jub : ',
	'info_inclusion_vignette' => 'Boole bu wiñet bi : ',
	'info_installer_tous_documents' => 'Sampal jukki yépp.',
	'info_telecharger' => 'Yebeel ci sa ordinatëer.',

	// T
	'texte_documents_joints' => 'Vous pouvez autoriser l’ajout de documents (fichiers bureautiques, images,
 multimédia, etc.) aux articles et/ou aux rubriques. Ces fichiers
 peuvent ensuite être référencés dans
 l’article, ou affichés séparément.', # MODIF

	// U
	'upload_fichier_zip' => 'Dencukaay Zip.',
	'upload_fichier_zip_texte' => 'Dencukaay bi nga bëgg samp dencukaay zip la.',
	'upload_fichier_zip_texte2' => 'Dencukaay bi mën na.',
	'upload_limit' => 'Dencukaay bi dafa rëy lool ci serwëer bi dayo bi gëna mag te nu daganal ko lii la. @max@.',
	'upload_zip_decompacter' => 'Nagu na ba noppi mbir mu ne ci biir sampu na ci dàl bi. Su ko defee dencukaay yi nara sampu ci dà bi ñooy. ',
	'upload_zip_telquel' => 'Ñu sampleen noonu ñu nekk baston bu nagu ci najub Zip.'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_wo.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=wo
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_ajouter_document' => 'Dolli ab jukki', # MODIF
	'bouton_ajouter_image' => 'Dolli ab nataal', # MODIF

	// E
	'entree_dimensions' => 'Tolluwaay yi',
	'entree_titre_document' => 'Boppu jukki bi',
	'entree_titre_image' => 'Boppu nataal bi',

	// I
	'image_tourner_180' => 'Wëndeel 180°',
	'image_tourner_droite' => 'Wëndeel 90° ci ndeyjoor',
	'image_tourner_gauche' => 'Wëndeel 90° ci cammooñ',
	'info_document' => 'Jukku;',
	'info_documents' => 'Jukk;',
	'info_inclusion_directe' => 'Boole bu jub : ',
	'info_inclusion_vignette' => 'Boole bu wiñet bi : ',
	'info_installer_tous_documents' => 'Sampal jukki yépp.',
	'info_telecharger' => 'Yebeel ci sa ordinatëer.',

	// T
	'texte_documents_joints' => 'Vous pouvez autoriser l’ajout de documents (fichiers bureautiques, images,
 multimédia, etc.) aux articles et/ou aux rubriques. Ces fichiers
 peuvent ensuite être référencés dans
 l’article, ou affichés séparément.', # MODIF

	// U
	'upload_fichier_zip' => 'Dencukaay Zip.',
	'upload_fichier_zip_texte' => 'Dencukaay bi nga bëgg samp dencukaay zip la.',
	'upload_fichier_zip_texte2' => 'Dencukaay bi mën na.',
	'upload_limit' => 'Dencukaay bi dafa rëy lool ci serwëer bi dayo bi gëna mag te nu daganal ko lii la. @max@.',
	'upload_zip_decompacter' => 'Nagu na ba noppi mbir mu ne ci biir sampu na ci dàl bi. Su ko defee dencukaay yi nara sampu ci dà bi ñooy. ',
	'upload_zip_telquel' => 'Ñu sampleen noonu ñu nekk baston bu nagu ci najub Zip.',
];
